(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24035,        811]*)
(*NotebookOutlinePosition[     24701,        834]*)
(*  CellTagsIndexPosition[     24657,        830]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(SetDirectory["\<d:\\demolattices\>"]\)], "Input"],

Cell[BoxData[
    \("d:\\demolattices"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Get["\<LaxPairLattices.m\>"]\)], "Input"],

Cell[BoxData[
    \("Loading code for computation of Lax pair of lattices (July 12, \
2008)"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("***************** MENU INTERFACE *****************  \
(page: "\[InvisibleSpace]1\[InvisibleSpace]")"\),
      SequenceForm[ 
      "***************** MENU INTERFACE *****************  (page: ", 1, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("---------------------------------------------------------------------"\
\)], "Print"],

Cell[BoxData[
    \("  1) discrete potential KdV Equation (l_pKdV.m)"\)], "Print"],

Cell[BoxData[
    \("  2) discrete modified KdV Equation  (l_mKdV.m)"\)], "Print"],

Cell[BoxData[
    \("  3) discrete sine-Gordon Equation (l_sG.m)"\)], "Print"],

Cell[BoxData[
    \("  4) H1 equation (ABS classification) (l_H1.m)"\)], "Print"],

Cell[BoxData[
    \("  5) H2 equation (ABS classification) (l_H2.m)"\)], "Print"],

Cell[BoxData[
    \("  6) H3 equation (delta not 0) (ABS classification) (l_H3rhs.m)"\)], \
"Print"],

Cell[BoxData[
    \("  7) H3 equation (delta = 0) (ABS classification) (l_H3zero.m)"\)], \
"Print"],

Cell[BoxData[
    \("  8) Q1 equation (delta not 0) (ABS classification) (l_Q1rhs.m)"\)], \
"Print"],

Cell[BoxData[
    \("  9) Q1 equation (delta = 0) (ABS classification) (l_Q1zero.m)"\)], \
"Print"],

Cell[BoxData[
    \("  10) Q2 equation (delta not 0) (ABS classification) (l_Q2rhs.m)"\)], \
"Print"],

Cell[BoxData[
    \(" nn) Next Page"\)], "Print"],

Cell[BoxData[
    \(" tt) Your System"\)], "Print"],

Cell[BoxData[
    \(" qq) Exit the Program"\)], "Print"],

Cell[BoxData[
    \("---------------------------------------------------------------------"\
\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("***************** MENU INTERFACE *****************  \
(page: "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ 
      "***************** MENU INTERFACE *****************  (page: ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("---------------------------------------------------------------------"\
\)], "Print"],

Cell[BoxData[
    \("  11) Q2 equation (delta = 0) (ABS classification) (l_Q2zero.m)"\)], \
"Print"],

Cell[BoxData[
    \("  12) Q3 equation (delta not 0) (ABS classification) (l_Q3rhs.m)"\)], \
"Print"],

Cell[BoxData[
    \("  13) Q3 equation (delta = 0) (ABS classification) (l_Q3zero.m)"\)], \
"Print"],

Cell[BoxData[
    \("  14) A1 equation (delta not 0) (ABS classification) (l_A1rhs.m)"\)], \
"Print"],

Cell[BoxData[
    \("  15) A1 equation (delta = 0) (ABS classification) (l_A1zero.m)"\)], \
"Print"],

Cell[BoxData[
    \("  16) A2 equation (ABS classification) (l_A2.m)"\)], "Print"],

Cell[BoxData[
    \("  17) (alpha,beta) equation (l_abeq.m)"\)], "Print"],

Cell[BoxData[
    \("  18) discrete sine-Gordon Equation (testing parameters) \
(l_sGpar.m)"\)], "Print"],

Cell[BoxData[
    \(" nn) Next Page"\)], "Print"],

Cell[BoxData[
    \(" tt) Your System"\)], "Print"],

Cell[BoxData[
    \(" qq) Exit the Program"\)], "Print"],

Cell[BoxData[
    \("---------------------------------------------------------------------"\
\)], "Print"],

Cell[BoxData[
    \("********************************************************************"\)\
], "Print"],

Cell[BoxData[
    \("         WELCOME TO THE MATHEMATICA PROGRAM              "\)], "Print"],

Cell[BoxData[
    \("                  by WILLY HEREMAN                       "\)], "Print"],

Cell[BoxData[
    \("     FOR THE COMPUTATION OF LAX PAIRS OF NONLINEAR       "\)], "Print"],

Cell[BoxData[
    \("  PARTIAL DIFFERENCE EQUATIONS IN 2D (ON QUAD-GRAPHS)    "\)], "Print"],

Cell[BoxData[
    \(" Collaborators: Reinout Quispel and Peter van der Kamp   "\)], "Print"],

Cell[BoxData[
    \("           First released on July 12, 2008               "\)], "Print"],

Cell[BoxData[
    \("                    Copyright 2008                       "\)], "Print"],

Cell[BoxData[
    \("********************************************************************"\)\
], "Print"],

Cell[BoxData[
    InterpretationBox[\("Working with the discrete "\[InvisibleSpace]sGpar\
\[InvisibleSpace]" equation:"\),
      SequenceForm[ "Working with the discrete ", sGpar, " equation:"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(-1\) + x\ x1\ x12\ x2 - p\ q\ \((x\ x12 - x1\ x2)\) \[Equal] 
      0\)], "Print"],

Cell[BoxData[
    \("********************** CONTROL SETTINGS *************************"\)], \
"Print"],

Cell[BoxData[
    InterpretationBox[\("LaxPairGiven (L and M are given in data file) is set \
to "\[InvisibleSpace]True\),
      SequenceForm[ 
      "LaxPairGiven (L and M are given in data file) is set to ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("t and s are given in data file (byhand) is set to: "\
\[InvisibleSpace]False\),
      SequenceForm[ 
      "t and s are given in data file (byhand) is set to: ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Determinant method to compute t and s is set to: "\
\[InvisibleSpace]True\),
      SequenceForm[ 
      "Determinant method to compute t and s is set to: ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Test consistency on cube is set to \
"\[InvisibleSpace]True\),
      SequenceForm[ "Test consistency on cube is set to ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Use of powerexpand is set to "\[InvisibleSpace]False\
\),
      SequenceForm[ "Use of powerexpand is set to ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Use of rootrules is set to "\[InvisibleSpace]True\),
      SequenceForm[ "Use of rootrules is set to ", True],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computation of matrix N is set to: \
"\[InvisibleSpace]False\),
      SequenceForm[ "Computation of matrix N is set to: ", False],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Application of gauge transformation is set to: "\
\[InvisibleSpace]False\),
      SequenceForm[ "Application of gauge transformation is set to: ", False],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \("******************* START OF THE COMPUTATION ************************"\
\)], "Print"],

Cell[BoxData[
    \("Working with lattice defined on front (F), latticefront:"\)], "Print"],

Cell[BoxData[
    \(\(-1\) + x\ x1\ x12\ x2 - p\ q\ \((x\ x12 - x1\ x2)\) \[Equal] 
      0\)], "Print"],

Cell[BoxData[
    \("Lattice on ground (G), latticeground:"\)], "Print"],

Cell[BoxData[
    \(\(-1\) + x\ x1\ x13\ x3 - k\ p\ \((x\ x13 - x1\ x3)\) \[Equal] 
      0\)], "Print"],

Cell[BoxData[
    \("Lattice on left face (L), latticeleftface:"\)], "Print"],

Cell[BoxData[
    \(\(-1\) + x\ x2\ x23\ x3 - k\ q\ \((x\ x23 - x2\ x3)\) \[Equal] 
      0\)], "Print"],

Cell[BoxData[
    \("**************** TESTING CONSISTENCY AROUND THE CUBE ****************"\
\)], "Print"],

Cell[BoxData[
    \("Computation  x12 ="\)], "Print"],

Cell[BoxData[
    \(\(\(-1\) + p\ q\ x1\ x2\)\/\(x\ \((p\ q - x1\ x2)\)\)\)], "Print"],

Cell[BoxData[
    \("Computation  x13 = "\)], "Print"],

Cell[BoxData[
    \(\(\(-1\) + k\ p\ x1\ x3\)\/\(x\ \((k\ p - x1\ x3)\)\)\)], "Print"],

Cell[BoxData[
    \("Computation  x23 = "\)], "Print"],

Cell[BoxData[
    \(\(\(-1\) + k\ q\ x2\ x3\)\/\(x\ \((k\ q - x2\ x3)\)\)\)], "Print"],

Cell[BoxData[
    \("*****************************************************************"\)], \
"Print"],

Cell[BoxData[
    \("After factoring, computation of x123 using x23 (x123choice1), x123 \
="\)], "Print"],

Cell[BoxData[
    \(\((k\ q - k\ p\^2\ q\ x\^2 - k\ p\ q\^2\ x1\ x2 + k\ p\ x\^2\ x1\ x2 - 
          k\^2\ p\ q\ x1\ x3 + p\ q\ x\^2\ x1\ x3 + 
          k\^2\ p\^2\ q\^2\ x1\^2\ x2\ x3 - 
          x\^2\ x1\^2\ x2\ x3)\)/\((x1\ \((\(-1\) + k\^2\ p\^2\ q\^2\ x\^2 + 
              p\ q\ x1\ x2 - k\^2\ p\ q\ x\^2\ x1\ x2 + k\ p\ x1\ x3 - 
              k\ p\ q\^2\ x\^2\ x1\ x3 - k\ p\^2\ q\ x1\^2\ x2\ x3 + 
              k\ q\ x\^2\ x1\^2\ x2\ x3)\))\)\)], "Print"],

Cell[BoxData[
    \("After factoring, computation of x123 using x13, (x123choice2), x123 ="\
\)], "Print"],

Cell[BoxData[
    \(\((k\ p - k\ p\ q\^2\ x\^2 - k\ p\^2\ q\ x1\ x2 + k\ q\ x\^2\ x1\ x2 - 
          k\^2\ p\ q\ x2\ x3 + p\ q\ x\^2\ x2\ x3 + 
          k\^2\ p\^2\ q\^2\ x1\ x2\^2\ x3 - 
          x\^2\ x1\ x2\^2\ x3)\)/\((x2\ \((\(-1\) + k\^2\ p\^2\ q\^2\ x\^2 + 
              p\ q\ x1\ x2 - k\^2\ p\ q\ x\^2\ x1\ x2 + k\ q\ x2\ x3 - 
              k\ p\^2\ q\ x\^2\ x2\ x3 - k\ p\ q\^2\ x1\ x2\^2\ x3 + 
              k\ p\ x\^2\ x1\ x2\^2\ x3)\))\)\)], "Print"],

Cell[BoxData[
    \("********************************************************************"\)\
], "Print"],

Cell[BoxData[
    \("As soon as one consistency condition is violated the computation"\)], \
"Print"],

Cell[BoxData[
    \("will abort, unless candidates for L and M are given in the data file."\
\)], "Print"],

Cell[BoxData[
    \("Test if (x123choice1 - x123choice2) = 0, diffx123choice1choice2 ="\)], \
"Print"],

Cell[BoxData[
    \(k\ \((\(-p\)\ x1 + p\ q\^2\ x\^2\ x1 + q\ x2 - p\^2\ q\ x\^2\ x2 + 
          p\^2\ q\ x1\^2\ x2 - q\ x\^2\ x1\^2\ x2 - p\ q\^2\ x1\ x2\^2 + 
          p\ x\^2\ x1\ x2\^2)\)\ \((\(-1\) + k\^2\ p\^2\ q\^2\ x\^2 + 
          p\ q\ x1\ x2 - k\^2\ p\ q\ x\^2\ x1\ x2 + k\ p\ x1\ x3 - 
          k\ p\ q\^2\ x\^2\ x1\ x3 + k\ q\ x2\ x3 - 
          k\ p\^2\ q\ x\^2\ x2\ x3 - k\ p\^2\ q\ x1\^2\ x2\ x3 + 
          k\ q\ x\^2\ x1\^2\ x2\ x3 - k\ p\ q\^2\ x1\ x2\^2\ x3 + 
          k\ p\ x\^2\ x1\ x2\^2\ x3 - k\^2\ p\ q\ x1\ x2\ x3\^2 + 
          p\ q\ x\^2\ x1\ x2\ x3\^2 + k\^2\ p\^2\ q\^2\ x1\^2\ x2\^2\ x3\^2 - 
          x\^2\ x1\^2\ x2\^2\ x3\^2)\)\)], "Print"],

Cell[BoxData[
    \("The equation is INCONSISTENT around the cube!"\)], "Print"],

Cell[BoxData[
    \("********* TEST RESULT IS NOT ZERO! ************ numerator of \
diffx123choice1choice2 must be zero:"\)], "Print"],

Cell[BoxData[
    \(k\ \((\(-p\)\ x1 + p\ q\^2\ x\^2\ x1 + q\ x2 - p\^2\ q\ x\^2\ x2 + 
          p\^2\ q\ x1\^2\ x2 - q\ x\^2\ x1\^2\ x2 - p\ q\^2\ x1\ x2\^2 + 
          p\ x\^2\ x1\ x2\^2)\)\ \((\(-1\) + k\^2\ p\^2\ q\^2\ x\^2 + 
          p\ q\ x1\ x2 - k\^2\ p\ q\ x\^2\ x1\ x2 + k\ p\ x1\ x3 - 
          k\ p\ q\^2\ x\^2\ x1\ x3 + k\ q\ x2\ x3 - 
          k\ p\^2\ q\ x\^2\ x2\ x3 - k\ p\^2\ q\ x1\^2\ x2\ x3 + 
          k\ q\ x\^2\ x1\^2\ x2\ x3 - k\ p\ q\^2\ x1\ x2\^2\ x3 + 
          k\ p\ x\^2\ x1\ x2\^2\ x3 - k\^2\ p\ q\ x1\ x2\ x3\^2 + 
          p\ q\ x\^2\ x1\ x2\ x3\^2 + k\^2\ p\^2\ q\^2\ x1\^2\ x2\^2\ x3\^2 - 
          x\^2\ x1\^2\ x2\^2\ x3\^2)\)\)], "Print"],

Cell[BoxData[
    \("Continue with the verification of the given Lax pair!"\)], "Print"],

Cell[BoxData[
    \("*********************************************************************"\
\)], "Print"],

Cell[BoxData[
    \("************* VERIFICATION OF THE GIVEN LAX PAIR ****************"\)], \
"Print"],

Cell[BoxData[
    \("The subsequent computations might be slow for complicated lattices, in \
particular, if square roots are present!"\)], "Print"],

Cell[BoxData[
    \("******* The matrix L was given in the data file! ******"\)], "Print"],

Cell[BoxData[
    \("Candidate Lax pair, matrix L (candidateL)"\)], "Print"],

Cell[BoxData[
    \("L = "\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"SSS", \(\(-TTT\)\ x1\)},
            {\(-\(TTT\/x\)\), \(\(SSS\ x1\)\/x\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("*********************************************************************"\
\)], "Print"],

Cell[BoxData[
    \("Entry L11 of candidate L (entrycandidateL11) "\)], "Print"],

Cell[BoxData[
    \("L11 = "\)], "Print"],

Cell[BoxData[
    \(SSS\)], "Print"],

Cell[BoxData[
    \("Entry L12 of candidate L (entrycandidateL12) "\)], "Print"],

Cell[BoxData[
    \("L12 = "\)], "Print"],

Cell[BoxData[
    \(\(-TTT\)\ x1\)], "Print"],

Cell[BoxData[
    \("Entry L21 of candidate L (entrycandidateL21) "\)], "Print"],

Cell[BoxData[
    \("L21 = "\)], "Print"],

Cell[BoxData[
    \(\(-\(TTT\/x\)\)\)], "Print"],

Cell[BoxData[
    \("Entry L22 of candidate L (entrycandidateL22) "\)], "Print"],

Cell[BoxData[
    \("L22 = "\)], "Print"],

Cell[BoxData[
    \(\(SSS\ x1\)\/x\)], "Print"],

Cell[BoxData[
    \("*********************************************************************"\
\)], "Print"],

Cell[BoxData[
    \("****** The matrix M was given in the data file! ******"\)], "Print"],

Cell[BoxData[
    \("Candidate Lax pair, matrix M (candidateM)"\)], "Print"],

Cell[BoxData[
    \("M = "\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(UUU\ x2\)\/x\), \(-\(VVV\/x\)\)},
            {\(\(-VVV\)\ x2\), "UUU"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("*********************************************************************"\
\)], "Print"],

Cell[BoxData[
    \("Entry M11 of candidate M (entrycandidateM11) "\)], "Print"],

Cell[BoxData[
    \("M11 = "\)], "Print"],

Cell[BoxData[
    \(\(UUU\ x2\)\/x\)], "Print"],

Cell[BoxData[
    \("Entry M12 of candidate M (entrycandidateM12) "\)], "Print"],

Cell[BoxData[
    \("M12 = "\)], "Print"],

Cell[BoxData[
    \(\(-\(VVV\/x\)\)\)], "Print"],

Cell[BoxData[
    \("Entry M21 of candidate M (entrycandidateM21) "\)], "Print"],

Cell[BoxData[
    \("M21 = "\)], "Print"],

Cell[BoxData[
    \(\(-VVV\)\ x2\)], "Print"],

Cell[BoxData[
    \("Entry M22 of candidate M (entrycandidateM22) "\)], "Print"],

Cell[BoxData[
    \("M22 = "\)], "Print"],

Cell[BoxData[
    \(UUU\)], "Print"],

Cell[BoxData[
    \("******************************************************************"\)],\
 "Print"],

Cell[BoxData[
    \("*********** COMPUTATION OF CONSTRAINTS FOR t AND s \
***************"\)], "Print"],

Cell[BoxData[
    \("The subsequent computations might be slow for complicated \
lattices!"\)], "Print"],

Cell[BoxData[
    \("Compatibility equation, (1-1) element ON LATTICE,"\)], "Print"],

Cell[BoxData[
    \("compatibilityeq11onlattice = "\)], "Print"],

Cell[BoxData[
    \(\(-\(\(\((SSS\ UUU - p\ q\ TTT\ VVV)\)\ \((\(-1\) + x1\ x2)\)\ \((1 + 
                  x1\ x2)\)\)\/\(x\ x1\ \((p\ q - x1\ x2)\)\)\)\) \[Equal] 
      0\)], "Print"],

Cell[BoxData[
    \("Compatibility equation, (1-2) element ON LATTICE, "\)], "Print"],

Cell[BoxData[
    \("compatibilityeq12onlattice = "\)], "Print"],

Cell[BoxData[
    \(True\)], "Print"],

Cell[BoxData[
    \("Compatibility equation, (2-1) element ON LATTICE, "\)], "Print"],

Cell[BoxData[
    \("compatibilityeq21onlattice = "\)], "Print"],

Cell[BoxData[
    \(True\)], "Print"],

Cell[BoxData[
    \("Compatibility equation, (2-2) element ON LATTICE, "\)], "Print"],

Cell[BoxData[
    \("compatibilityeq22onlattice = "\)], "Print"],

Cell[BoxData[
    \(\(-\(\(\((SSS\ UUU - p\ q\ TTT\ VVV)\)\ \((\(-1\) + x1\ x2)\)\ \((1 + 
                  x1\ x2)\)\)\/\(x\ x1\ \((p\ q - x1\ x2)\)\)\)\) \[Equal] 
      0\)], "Print"],

Cell[BoxData[
    \("******************************************************************"\)],\
 "Print"],

Cell[BoxData[
    \("************** FINAL TEST OF THE COMPUTED LAX PAIR \
***************"\)], "Print"],

Cell[BoxData[
    \("The subsequent computations might be slow for complicated lattices, in \
particular, if square roots are present!"\)], "Print"],

Cell[BoxData[
    \("Candidate compatibility matrix L2.M - M1.L, ON LATTICE,"\)], "Print"],

Cell[BoxData[
    \("candidatecompatibilitymatrixonlattice ="\)], "Print"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-\(\(\((SSS\ UUU - p\ q\ TTT\ VVV)\)\ \((\(-1\) + 
                          x1\ x2)\)\ \((1 + x1\ x2)\)\)\/\(x\ x1\ \((p\ q - 
                          x1\ x2)\)\)\)\), "0"},
            {
              "0", \(\(\((SSS\ UUU - p\ q\ TTT\ VVV)\)\ \((\(-1\) + 
                        x1\ x2)\)\ \((1 + x1\ x2)\)\)\/\(x\ x2\ \((p\ q - 
                        x1\ x2)\)\)\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \("Either the Lax pair (given in the data file) does not satisfy"\)], \
"Print"],

Cell[BoxData[
    \("the Lax equation OR, more likely, Mathematica could not simplify"\)], \
"Print"],

Cell[BoxData[
    \("the resulting matrix."\)], "Print"],

Cell[BoxData[
    \("Matrix will be tested with 12 tests where the symbols"\)], "Print"],

Cell[BoxData[
    \("are replaced by randomly selected prime numbers."\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(37577106\ \((SSS\ UUU - 209\ TTT\ VVV)\)\)\/23826851, 
        0}, {0, \(-\(\(37577106\ \((SSS\ UUU - 
                    209\ TTT\ VVV)\)\)\/29089223\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(84658452\ \((SSS\ UUU - 57\ TTT\ VVV)\)\)\/58185955, 
        0}, {0, \(-\(\(84658452\ \((SSS\ UUU - 
                    57\ TTT\ VVV)\)\)\/66930665\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(278706330\ \((SSS\ UUU - 57\ TTT\ VVV)\)\)\/214799741, 
        0}, {0, \(-\(\(278706330\ \((SSS\ UUU - 
                    57\ TTT\ VVV)\)\)\/239632081\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(14613319\ \((SSS\ UUU - 253\ TTT\ VVV)\)\)\/9981957, 
        0}, {0, \(-\(\(14613319\ \((SSS\ UUU - 
                    253\ TTT\ VVV)\)\)\/12186561\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(825675\ \((SSS\ UUU - 69\ TTT\ VVV)\)\)\/593303, 
        0}, {0, \(-\(\(825675\ \((SSS\ UUU - 
                    69\ TTT\ VVV)\)\)\/729347\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(397831736\ \((SSS\ UUU - 62\ TTT\ VVV)\)\)\/281891885, 
        0}, {0, \(-\(\(397831736\ \((SSS\ UUU - 
                    62\ TTT\ VVV)\)\)\/303939295\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(395072776\ \((SSS\ UUU - 38\ TTT\ VVV)\)\)\/259785969, 
        0}, {0, \(-\(\(395072776\ \((SSS\ UUU - 
                    38\ TTT\ VVV)\)\)\/298828947\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(1185218328\ \((SSS\ UUU - 46\ TTT\ VVV)\)\)\/826759907, 
        0}, {0, \(-\(\(1185218328\ \((SSS\ UUU - 
                    46\ TTT\ VVV)\)\)\/951012841\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(1243479168\ \((SSS\ UUU - 62\ TTT\ VVV)\)\)\/875836081, 
        0}, {0, \(-\(\(1243479168\ \((SSS\ UUU - 
                    62\ TTT\ VVV)\)\)\/963908983\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(274349532\ \((SSS\ UUU - 51\ TTT\ VVV)\)\)\/177857921, 
        0}, {0, \(-\(\(274349532\ \((SSS\ UUU - 
                    51\ TTT\ VVV)\)\)\/239031983\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(552216144\ \((SSS\ UUU - 87\ TTT\ VVV)\)\)\/412385959, 
        0}, {0, \(-\(\(552216144\ \((SSS\ UUU - 
                    87\ TTT\ VVV)\)\)\/491406023\)\)}}\)], "Print"],

Cell[BoxData[
    \("Numerical test failed, check if result is free of parameters"\)], \
"Print"],

Cell[BoxData[
    \("numericTestValue = "\)], "Print"],

Cell[BoxData[
    \({{\(21481590\ \((SSS\ UUU - 95\ TTT\ VVV)\)\)\/14894777, 
        0}, {0, \(-\(\(21481590\ \((SSS\ UUU - 
                    95\ TTT\ VVV)\)\)\/18001663\)\)}}\)], "Print"],

Cell[BoxData[
    \("Upon substitution into the Lax equation, the Lax pair"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("(given in the data file), FAILED \
"\[InvisibleSpace]12\),
      SequenceForm[ "(given in the data file), FAILED ", 12],
      Editable->False]], "Print"],

Cell[BoxData[
    \("of the 12 numeric tests (based on randomly selected prime \
numbers)."\)], "Print"],

Cell[BoxData[
    \("Turn debug flags on and retest the Lax pair!"\)], "Print"],

Cell[BoxData[
    \("*********************************************************************"\
\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Total CPU time used in the current session is "\
\[InvisibleSpace]4\[InvisibleSpace]" seconds."\),
      SequenceForm[ 
      "Total CPU time used in the current session is ", 4, " seconds."],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Code of July 12, 2008 was successfully loaded."\)], "Print"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
WindowSize->{1112, 740},
WindowMargins->{{Automatic, 44}, {Automatic, 25}},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 69, 1, 42, "Input"],
Cell[1848, 56, 52, 1, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1937, 62, 61, 1, 42, "Input"],
Cell[2001, 65, 105, 2, 35, "Print"],
Cell[2109, 69, 275, 5, 35, "Print"],
Cell[2387, 76, 106, 2, 35, "Print"],
Cell[2496, 80, 82, 1, 35, "Print"],
Cell[2581, 83, 82, 1, 35, "Print"],
Cell[2666, 86, 78, 1, 35, "Print"],
Cell[2747, 89, 81, 1, 35, "Print"],
Cell[2831, 92, 81, 1, 35, "Print"],
Cell[2915, 95, 100, 2, 35, "Print"],
Cell[3018, 99, 99, 2, 35, "Print"],
Cell[3120, 103, 100, 2, 35, "Print"],
Cell[3223, 107, 99, 2, 35, "Print"],
Cell[3325, 111, 101, 2, 35, "Print"],
Cell[3429, 115, 49, 1, 35, "Print"],
Cell[3481, 118, 51, 1, 35, "Print"],
Cell[3535, 121, 56, 1, 35, "Print"],
Cell[3594, 124, 106, 2, 35, "Print"],
Cell[3703, 128, 275, 5, 35, "Print"],
Cell[3981, 135, 106, 2, 35, "Print"],
Cell[4090, 139, 100, 2, 35, "Print"],
Cell[4193, 143, 101, 2, 35, "Print"],
Cell[4297, 147, 100, 2, 35, "Print"],
Cell[4400, 151, 101, 2, 35, "Print"],
Cell[4504, 155, 100, 2, 35, "Print"],
Cell[4607, 159, 82, 1, 35, "Print"],
Cell[4692, 162, 73, 1, 35, "Print"],
Cell[4768, 165, 105, 2, 35, "Print"],
Cell[4876, 169, 49, 1, 35, "Print"],
Cell[4928, 172, 51, 1, 35, "Print"],
Cell[4982, 175, 56, 1, 35, "Print"],
Cell[5041, 178, 106, 2, 35, "Print"],
Cell[5150, 182, 105, 2, 35, "Print"],
Cell[5258, 186, 92, 1, 35, "Print"],
Cell[5353, 189, 92, 1, 35, "Print"],
Cell[5448, 192, 92, 1, 35, "Print"],
Cell[5543, 195, 92, 1, 35, "Print"],
Cell[5638, 198, 92, 1, 35, "Print"],
Cell[5733, 201, 92, 1, 35, "Print"],
Cell[5828, 204, 92, 1, 35, "Print"],
Cell[5923, 207, 105, 2, 35, "Print"],
Cell[6031, 211, 228, 4, 35, "Print"],
Cell[6262, 217, 104, 2, 35, "Print"],
Cell[6369, 221, 102, 2, 35, "Print"],
Cell[6474, 225, 250, 5, 35, "Print"],
Cell[6727, 232, 242, 5, 35, "Print"],
Cell[6972, 239, 236, 5, 35, "Print"],
Cell[7211, 246, 201, 4, 35, "Print"],
Cell[7415, 252, 191, 4, 35, "Print"],
Cell[7609, 258, 183, 3, 35, "Print"],
Cell[7795, 263, 203, 4, 35, "Print"],
Cell[8001, 269, 234, 5, 35, "Print"],
Cell[8238, 276, 106, 2, 35, "Print"],
Cell[8347, 280, 91, 1, 35, "Print"],
Cell[8441, 283, 104, 2, 35, "Print"],
Cell[8548, 287, 72, 1, 35, "Print"],
Cell[8623, 290, 104, 2, 35, "Print"],
Cell[8730, 294, 77, 1, 35, "Print"],
Cell[8810, 297, 104, 2, 35, "Print"],
Cell[8917, 301, 106, 2, 35, "Print"],
Cell[9026, 305, 53, 1, 35, "Print"],
Cell[9082, 308, 86, 1, 54, "Print"],
Cell[9171, 311, 54, 1, 35, "Print"],
Cell[9228, 314, 86, 1, 54, "Print"],
Cell[9317, 317, 54, 1, 35, "Print"],
Cell[9374, 320, 86, 1, 54, "Print"],
Cell[9463, 323, 102, 2, 35, "Print"],
Cell[9568, 327, 105, 2, 35, "Print"],
Cell[9676, 331, 468, 7, 89, "Print"],
Cell[10147, 340, 106, 2, 35, "Print"],
Cell[10256, 344, 468, 7, 89, "Print"],
Cell[10727, 353, 105, 2, 35, "Print"],
Cell[10835, 357, 101, 2, 35, "Print"],
Cell[10939, 361, 106, 2, 35, "Print"],
Cell[11048, 365, 102, 2, 35, "Print"],
Cell[11153, 369, 684, 10, 115, "Print"],
Cell[11840, 381, 80, 1, 35, "Print"],
Cell[11923, 384, 134, 2, 60, "Print"],
Cell[12060, 388, 684, 10, 115, "Print"],
Cell[12747, 400, 88, 1, 35, "Print"],
Cell[12838, 403, 106, 2, 35, "Print"],
Cell[12947, 407, 102, 2, 35, "Print"],
Cell[13052, 411, 148, 2, 60, "Print"],
Cell[13203, 415, 90, 1, 35, "Print"],
Cell[13296, 418, 76, 1, 35, "Print"],
Cell[13375, 421, 39, 1, 35, "Print"],
Cell[13417, 424, 268, 7, 64, "Print"],
Cell[13688, 433, 106, 2, 35, "Print"],
Cell[13797, 437, 80, 1, 35, "Print"],
Cell[13880, 440, 41, 1, 35, "Print"],
Cell[13924, 443, 36, 1, 35, "Print"],
Cell[13963, 446, 80, 1, 35, "Print"],
Cell[14046, 449, 41, 1, 35, "Print"],
Cell[14090, 452, 45, 1, 35, "Print"],
Cell[14138, 455, 80, 1, 35, "Print"],
Cell[14221, 458, 41, 1, 35, "Print"],
Cell[14265, 461, 48, 1, 50, "Print"],
Cell[14316, 464, 80, 1, 35, "Print"],
Cell[14399, 467, 41, 1, 35, "Print"],
Cell[14443, 470, 47, 1, 51, "Print"],
Cell[14493, 473, 106, 2, 35, "Print"],
Cell[14602, 477, 89, 1, 35, "Print"],
Cell[14694, 480, 76, 1, 35, "Print"],
Cell[14773, 483, 39, 1, 35, "Print"],
Cell[14815, 486, 268, 7, 64, "Print"],
Cell[15086, 495, 106, 2, 35, "Print"],
Cell[15195, 499, 80, 1, 35, "Print"],
Cell[15278, 502, 41, 1, 35, "Print"],
Cell[15322, 505, 47, 1, 51, "Print"],
Cell[15372, 508, 80, 1, 35, "Print"],
Cell[15455, 511, 41, 1, 35, "Print"],
Cell[15499, 514, 48, 1, 50, "Print"],
Cell[15550, 517, 80, 1, 35, "Print"],
Cell[15633, 520, 41, 1, 35, "Print"],
Cell[15677, 523, 45, 1, 35, "Print"],
Cell[15725, 526, 80, 1, 35, "Print"],
Cell[15808, 529, 41, 1, 35, "Print"],
Cell[15852, 532, 36, 1, 35, "Print"],
Cell[15891, 535, 103, 2, 35, "Print"],
Cell[15997, 539, 103, 2, 35, "Print"],
Cell[16103, 543, 104, 2, 35, "Print"],
Cell[16210, 547, 84, 1, 35, "Print"],
Cell[16297, 550, 64, 1, 35, "Print"],
Cell[16364, 553, 187, 3, 54, "Print"],
Cell[16554, 558, 85, 1, 35, "Print"],
Cell[16642, 561, 64, 1, 35, "Print"],
Cell[16709, 564, 37, 1, 35, "Print"],
Cell[16749, 567, 85, 1, 35, "Print"],
Cell[16837, 570, 64, 1, 35, "Print"],
Cell[16904, 573, 37, 1, 35, "Print"],
Cell[16944, 576, 85, 1, 35, "Print"],
Cell[17032, 579, 64, 1, 35, "Print"],
Cell[17099, 582, 187, 3, 54, "Print"],
Cell[17289, 587, 103, 2, 35, "Print"],
Cell[17395, 591, 103, 2, 35, "Print"],
Cell[17501, 595, 148, 2, 60, "Print"],
Cell[17652, 599, 90, 1, 35, "Print"],
Cell[17745, 602, 74, 1, 35, "Print"],
Cell[17822, 605, 568, 12, 86, "Print"],
Cell[18393, 619, 98, 2, 35, "Print"],
Cell[18494, 623, 101, 2, 35, "Print"],
Cell[18598, 627, 56, 1, 35, "Print"],
Cell[18657, 630, 88, 1, 35, "Print"],
Cell[18748, 633, 83, 1, 35, "Print"],
Cell[18834, 636, 97, 2, 35, "Print"],
Cell[18934, 640, 54, 1, 35, "Print"],
Cell[18991, 643, 194, 3, 51, "Print"],
Cell[19188, 648, 97, 2, 35, "Print"],
Cell[19288, 652, 54, 1, 35, "Print"],
Cell[19345, 655, 192, 3, 51, "Print"],
Cell[19540, 660, 97, 2, 35, "Print"],
Cell[19640, 664, 54, 1, 35, "Print"],
Cell[19697, 667, 196, 3, 51, "Print"],
Cell[19896, 672, 97, 2, 35, "Print"],
Cell[19996, 676, 54, 1, 35, "Print"],
Cell[20053, 679, 193, 3, 51, "Print"],
Cell[20249, 684, 97, 2, 35, "Print"],
Cell[20349, 688, 54, 1, 35, "Print"],
Cell[20406, 691, 184, 3, 51, "Print"],
Cell[20593, 696, 97, 2, 35, "Print"],
Cell[20693, 700, 54, 1, 35, "Print"],
Cell[20750, 703, 196, 3, 51, "Print"],
Cell[20949, 708, 97, 2, 35, "Print"],
Cell[21049, 712, 54, 1, 35, "Print"],
Cell[21106, 715, 196, 3, 51, "Print"],
Cell[21305, 720, 97, 2, 35, "Print"],
Cell[21405, 724, 54, 1, 35, "Print"],
Cell[21462, 727, 198, 3, 51, "Print"],
Cell[21663, 732, 97, 2, 35, "Print"],
Cell[21763, 736, 54, 1, 35, "Print"],
Cell[21820, 739, 198, 3, 51, "Print"],
Cell[22021, 744, 97, 2, 35, "Print"],
Cell[22121, 748, 54, 1, 35, "Print"],
Cell[22178, 751, 196, 3, 51, "Print"],
Cell[22377, 756, 97, 2, 35, "Print"],
Cell[22477, 760, 54, 1, 35, "Print"],
Cell[22534, 763, 196, 3, 51, "Print"],
Cell[22733, 768, 97, 2, 35, "Print"],
Cell[22833, 772, 54, 1, 35, "Print"],
Cell[22890, 775, 192, 3, 51, "Print"],
Cell[23085, 780, 88, 1, 35, "Print"],
Cell[23176, 783, 193, 4, 35, "Print"],
Cell[23372, 789, 104, 2, 35, "Print"],
Cell[23479, 793, 79, 1, 35, "Print"],
Cell[23561, 796, 106, 2, 35, "Print"],
Cell[23670, 800, 265, 5, 35, "Print"],
Cell[23938, 807, 81, 1, 35, "Print"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

